@@ -1,7 +1,8 @@
-# $Id: HTMLResultWriter.pm 14697 2008-06-04 14:22:22Z heikki $
 #
 # BioPerl module for Bio::SearchIO::Writer::HTMLResultWriter
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Jason Stajich <jason@bioperl.org>
 #
 # Copyright Jason Stajich
@@ -67,13 +68,24 @@ the Bioperl mailing list.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Jason Stajich
 
@@ -99,7 +111,7 @@ use vars qw(%RemoteURLDefault
 # Object preamble - inherits from Bio::Root::RootI
 
 BEGIN {
-    $Revision = '$Id: HTMLResultWriter.pm 14697 2008-06-04 14:22:22Z heikki $';
+    $Revision = '$Id$';
     $DATE = localtime(time);
     %RemoteURLDefault = ( 
       'PROTEIN' => 'http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=protein&cmd=search&term=%s',			  
