@@ -76,7 +76,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  https://redmine.open-bio.org/projects/bioperl/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Sheldon McKay
 
@@ -147,9 +147,9 @@ sub new {
   my @result;
 
   if ($file) {
-      open FH, $file;
-      @result = (<FH>);
-      close FH;
+      open my $FH, '<', $file or $self->throw("Could not read file '$file': $!");
+      @result = (<$FH>);
+      close $FH;
   }
   elsif ($fh) {
       @result = (<$fh>);
